.. ACAT documentation master file, created by
   sphinx-quickstart on Fri Feb 19 01:27:02 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

ACAT: Alloy Catalysis Automated Toolkit
=======================================
Welcome to ACAT documentation! 

ACAT is a Python package for atomistic modelling of metal or alloy catalysts used in heterogeneous catalysis. The package is based on automatic identifications of adsorption sites and adsorbate coverages on surface slabs and nanoparticles. Synergized with ASE, ACAT provides useful tools for building atomistic models of alloy catalysts with and without adsorbates. The goal is to automate workflows so that the structure generations can be readily adapted in a high-throughput screening. 

ACAT has been developed by Shuang Han at the Section of Atomic Scale Materials Modelling, Department of Energy Conversion and Storage, Technical University of Denmark (DTU) in Lyngby, Denmark. The development is hosted on `gitlab
<https://gitlab.com/asm-dtu/acat.git>`_.

Contents
========
.. toctree::
   :maxdepth: 2

   Installation <installation.rst>
   Base modules <modules.rst>
   Building things <build.rst>
   Genetic algorithm <ga.rst>
   Other utilities <utilities.rst>
   Notes <notes.rst>

Gallery
=======
Various shapes and facets of nanoparticles identified by ACAT:

.. image:: ../images/color_facets.png
   :align: center

All symmetry-inequivalent adsorptions sites (in red) identified by ACAT on truncated octahedron (top left), fcc(311) surface (top right), hcp(10-10) surface (bottom left) and bcc(110) surface (bottom right):

.. image:: ../images/unique_sites.png
   :scale: 50 %
   :align: center

Well-defined ordered adsorbate overlayer patterns at various coverages for various surfaces and nanoparticles generated by ACAT:

.. image:: ../images/all_ordered_coverage_patterns.png
   :align: center

Acknowledgement
===============
The ACAT code is developed as part of the project BIKE: BImetallic catalysts Knowledge-based development for Energy applications. The BIKE project has received funding from the European Union’s Horizon 2020 Research and Innovation programme under the Marie Skłodowska-Curie Action – International Training Network (MSCA-ITN), grant agreement 813748

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
